import React, { FC, useContext, useEffect, useState } from "react";
import { EventContext, Styled } from "direflow-component";
import styles from "./App.css";
import VideoJS from "./Video";

interface IProps {
  options: any[];
  videoClass?: string;
  videoStyle?: any;
  selectStyle?: any;
}

const App: FC<IProps> = (props) => {
  const dispatch = useContext(EventContext);
  const playerRef = React.useRef<any>(null);
  const { options, videoStyle, selectStyle } = props;
  const [selectedVideo, setSelectedVideo] = useState<any>();
  useEffect(() => {
    if (options) {
      if (options.length) {
        setSelectedVideo(options[0]);
      }
    }
    return () => {};
  }, [options]);
  React.useEffect(() => {
    return () => {
      if (playerRef.current) {
        playerRef.current.dispose();
        playerRef.current = null;
      }
    };
  }, []);
  return (
    <Styled styles={styles} scoped={false}>
      <div className="container">
        <select
          style={selectStyle}
          className="form-select"
          aria-label="Default select example"
          onChange={(e) => {
            const o = options.find((a) => a.id == e.target.value);
            console.log("o", o, e.target.value);

            setSelectedVideo(o);
          }}
        >
          {options &&
            options.map((a) => {
              return <option value={a.id}>{a.title}</option>;
            })}
        </select>
        <div>
          {selectedVideo && (
            <video
              style={{ ...videoStyle }}
              className="videoClass"
              ref={playerRef}
              controls
              src={selectedVideo.sources[0]}
            />
          )}
        </div>
      </div>
    </Styled>
  );
};

App.defaultProps = {
  options: [],
  videoStyle: {},
  selectStyle: {},
};

export default App;
